Struct relm_core::EventStream
[−]
[src]
pub struct EventStream<MSG> { /* fields omitted */ }A stream of messages to be used for widget/signal communication and inter-widget communication.
Methods
impl<MSG> EventStream<MSG>[src]
pub fn new() -> Self[src]
Create a new event stream.
pub fn close(&self)[src]
Close the event stream, i.e. stop processing messages.
pub fn emit(&self, event: MSG)[src]
Send the event message to the stream and the observers.
pub fn lock(&self) -> Lock<MSG>[src]
Lock the stream (don't emit message) until the Lock goes out of scope.
pub fn observe<CALLBACK: Fn(&MSG) + 'static>(&self, callback: CALLBACK)[src]
Add an observer to the event stream. This callback will be called every time a message is emmited.
pub fn set_callback<CALLBACK: FnMut(MSG) + 'static>(&self, callback: CALLBACK)[src]
Add a callback to the event stream. This is the main callback and received a owned version of the message, in contrast to observe().